==> zio-aws-ssoadmin_3-5.17.113.1-sources.jar: zio/aws/ssoadmin/model/DescribeAccountAssignmentDeletionStatusResponse.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeAccountAssignmentDeletionStatusResponse(
    accountAssignmentDeletionStatus: Option[
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse = {
    import DescribeAccountAssignmentDeletionStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
      .builder()
      .optionallyWith(
        accountAssignmentDeletionStatus.map(value => value.buildAwsValue())
      )(_.accountAssignmentDeletionStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse.ReadOnly =
    zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
      .wrap(buildAwsValue())
}
object DescribeAccountAssignmentDeletionStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse =
      zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse(
        accountAssignmentDeletionStatus.map(value => value.asEditable)
      )
    def accountAssignmentDeletionStatus: Option[
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.ReadOnly
    ]
    def getAccountAssignmentDeletionStatus: ZIO[
      Any,
      AwsError,
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.ReadOnly
    ] = AwsError.unwrapOptionField(
      "accountAssignmentDeletionStatus",
      accountAssignmentDeletionStatus
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
  ) extends zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse.ReadOnly {
    override val accountAssignmentDeletionStatus: Option[
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.ReadOnly
    ] = scala
      .Option(impl.accountAssignmentDeletionStatus())
      .map(value =>
        zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
  ): zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ssoadmin_3-5.17.267.6-sources.jar: zio/aws/ssoadmin/model/DescribeAccountAssignmentDeletionStatusResponse.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DescribeAccountAssignmentDeletionStatusResponse(
    accountAssignmentDeletionStatus: Optional[
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse = {
    import DescribeAccountAssignmentDeletionStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
      .builder()
      .optionallyWith(
        accountAssignmentDeletionStatus.map(value => value.buildAwsValue())
      )(_.accountAssignmentDeletionStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse.ReadOnly =
    zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
      .wrap(buildAwsValue())
}
object DescribeAccountAssignmentDeletionStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse =
      zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse(
        accountAssignmentDeletionStatus.map(value => value.asEditable)
      )
    def accountAssignmentDeletionStatus: Optional[
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.ReadOnly
    ]
    def getAccountAssignmentDeletionStatus: ZIO[
      Any,
      AwsError,
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.ReadOnly
    ] = AwsError.unwrapOptionField(
      "accountAssignmentDeletionStatus",
      accountAssignmentDeletionStatus
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
  ) extends zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse.ReadOnly {
    override val accountAssignmentDeletionStatus: Optional[
      zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.accountAssignmentDeletionStatus())
      .map(value =>
        zio.aws.ssoadmin.model.AccountAssignmentOperationStatus.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse
  ): zio.aws.ssoadmin.model.DescribeAccountAssignmentDeletionStatusResponse.ReadOnly =
    new Wrapper(impl)
}
